package App::Donburi;
use strict;
use warnings;
our $VERSION = '0.02';



1;
__END__

=encoding utf8

=head1 NAME

App::Donburi - Web to IRC Gateway

=head1 SYNOPSIS

  cpanm App::Donburi
  donburi

=head1 DESCRIPTION

Donburi is Web to IRC Gateway.

=head1 AUTHOR

Kan Fushihara E<lt>kan dot fushihara at gmail dot comE<gt>
Nishibayashi Takuji E<lt>takuji {at} senchan.jpE<gt>

=head1 SEE ALSO

=head1 LICENSE

Copyright (C) Kan Fushihara

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
